@@ -3,7 +3,7 @@ package Prty;
 use strict;
 use warnings;
 
-our $VERSION = 1.110;
+our $VERSION = 1.111;
 
 =encoding utf8
 
@@ -36,6 +36,10 @@ L<Prty::ClassConfig> - Verwalte Information auf Klassenebene
 
 =item *
 
+L<Prty::ClassLoader> - Load Perl classes automatically
+
+=item *
+
 L<Prty::Color> - Eine Farbe des RGB-Farbraums
 
 =item *
@@ -560,6 +564,14 @@ L<Prty::Terminal> - Ein- und Ausgabe aufs Terminal
 
 =item *
 
+L<Prty::Test::Class> - Basisklasse für Testklassen
+
+=item *
+
+L<Prty::Test::Class::Method> - Testmethode
+
+=item *
+
 L<Prty::TextFile> - Textdatei als Array von Zeilen
 
 =item *
@@ -622,7 +634,7 @@ L<Prty::Xml::LibXml> - Funktionale Erweiterungen von XML::LibXML
 
 =head1 VERSION
 
-1.110
+1.111
 
 =head1 AUTHOR
 
